==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_loworderfee.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_loworderfee.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_ORDER_TOTAL_LOWORDERFEE_DESCRIPTION' => 'Zuschlag bei Unterschreitung des Mindestbestellwertes',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_DESC' => 'Mindestmengenzuschlag für Bestellungen, die an diesen Ort versandt werden.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_TITLE' => 'Mindestmengenzuschlag nach Zonen berechnen',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_DESC' => 'Mindermengenzuschlag.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_TITLE' => 'Zuschlag',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_DESC' => 'Möchten Sie Mindermengenzuschläge erlauben?',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_TITLE' => 'Mindermengenzuschlag erlauben',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_DESC' => 'Mindermengenzuschlag wird für Bestellungen unter diesem Wert hinzugefügt.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_TITLE' => 'Mindermengenzuschlag für Bestellungen unter',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_DESC' => 'Anzeigereihenfolge.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_DESC' => 'Möchten Sie sich den Mindermengenzuschlag ansehen?',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_TITLE' => 'Mindermengenzuschlag anzeigen',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_DESC' => 'Folgende Steuerklasse für den Mindermengenzuschlag verwenden.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_TITLE' => 'Mindermengenzuschlag'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_loworderfee.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_loworderfee.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_ORDER_TOTAL_LOWORDERFEE_DESCRIPTION' => 'Zuschlag bei Unterschreitung des Mindestbestellwertes',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_DESC' => 'Mindestmengenzuschlag für Bestellungen, die an diesen Ort versandt werden.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_TITLE' => 'Mindestmengenzuschlag nach Zonen berechnen',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_DESC' => 'Mindermengenzuschlag.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_TITLE' => 'Zuschlag',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_DESC' => 'Möchtest du den Mindermengenzuschläge erlauben?',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_TITLE' => 'Mindermengenzuschlag erlauben',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_DESC' => 'Mindermengenzuschlag wird für Bestellungen unter diesem Wert hinzugefügt.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_TITLE' => 'Mindermengenzuschlag für Bestellungen unter',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_DESC' => 'Anzeigereihenfolge.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_DESC' => 'Möchtest du den Mindermengenzuschlag ansehen?',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_TITLE' => 'Mindermengenzuschlag anzeigen',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_DESC' => 'Folgende Steuerklasse für den Mindermengenzuschlag verwenden.',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_ORDER_TOTAL_LOWORDERFEE_TITLE' => 'Mindermengenzuschlag'
);
